@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # flake8: noqa: E501
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2023
+# Copyright (C) 2015-2024
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -53,35 +53,34 @@ class EncryptedPassportElement(TelegramObject):
             :class:`telegram.PassportElementErrorUnspecified`.
         data (:class:`telegram.PersonalDetails` | :class:`telegram.IdDocumentData` | \
             :class:`telegram.ResidentialAddress` | :obj:`str`, optional):
-            Decrypted or encrypted data, available for "personal_details", "passport",
+            Decrypted or encrypted data; available only for "personal_details", "passport",
             "driver_license", "identity_card", "internal_passport" and "address" types.
-        phone_number (:obj:`str`, optional): User's verified phone number, available only for
+        phone_number (:obj:`str`, optional): User's verified phone number; available only for
             "phone_number" type.
-        email (:obj:`str`, optional): User's verified email address, available only for "email"
+        email (:obj:`str`, optional): User's verified email address; available only for "email"
             type.
         files (Sequence[:class:`telegram.PassportFile`], optional): Array of encrypted/decrypted
-            files
-            with documents provided by the user, available for "utility_bill", "bank_statement",
-            "rental_agreement", "passport_registration" and "temporary_registration" types.
+            files with documents provided by the user; available only for "utility_bill", 
+            "bank_statement", "rental_agreement", "passport_registration" and 
+            "temporary_registration" types.
 
             .. versionchanged:: 20.0
                 |sequenceclassargs|
 
         front_side (:class:`telegram.PassportFile`, optional): Encrypted/decrypted file with the
-            front side of the document, provided by the user. Available for "passport",
+            front side of the document, provided by the user; Available only for "passport",
             "driver_license", "identity_card" and "internal_passport".
         reverse_side (:class:`telegram.PassportFile`, optional): Encrypted/decrypted file with the
-            reverse side of the document, provided by the user. Available for "driver_license" and
-            "identity_card".
+            reverse side of the document, provided by the user; Available only for
+            "driver_license" and "identity_card".
         selfie (:class:`telegram.PassportFile`, optional): Encrypted/decrypted file with the
-            selfie of the user holding a document, provided by the user; available for "passport",
-            "driver_license", "identity_card" and "internal_passport".
+            selfie of the user holding a document, provided by the user; available if requested for 
+            "passport", "driver_license", "identity_card" and "internal_passport".
         translation (Sequence[:class:`telegram.PassportFile`], optional): Array of
-            encrypted/decrypted
-            files with translated versions of documents provided by the user. Available if
-            requested for "passport", "driver_license", "identity_card", "internal_passport",
-            "utility_bill", "bank_statement", "rental_agreement", "passport_registration" and
-            "temporary_registration" types.
+            encrypted/decrypted files with translated versions of documents provided by the user; 
+            available if requested requested for "passport", "driver_license", "identity_card", 
+            "internal_passport", "utility_bill", "bank_statement", "rental_agreement", 
+            "passport_registration" and "temporary_registration" types.
 
             .. versionchanged:: 20.0
                 |sequenceclassargs|
@@ -95,16 +94,16 @@ class EncryptedPassportElement(TelegramObject):
             :class:`telegram.PassportElementErrorUnspecified`.
         data (:class:`telegram.PersonalDetails` | :class:`telegram.IdDocumentData` | \
             :class:`telegram.ResidentialAddress` | :obj:`str`):
-            Optional. Decrypted or encrypted data, available for "personal_details", "passport",
-            "driver_license", "identity_card", "internal_passport" and "address" types.
-        phone_number (:obj:`str`): Optional. User's verified phone number, available only for
+            Optional. Decrypted or encrypted data; available only for "personal_details",
+            "passport", "driver_license", "identity_card", "internal_passport" and "address" types.
+        phone_number (:obj:`str`): Optional. User's verified phone number; available only for
             "phone_number" type.
-        email (:obj:`str`): Optional. User's verified email address, available only for "email"
+        email (:obj:`str`): Optional. User's verified email address; available only for "email"
             type.
         files (Tuple[:class:`telegram.PassportFile`]): Optional. Array of encrypted/decrypted
-            files
-            with documents provided by the user, available for "utility_bill", "bank_statement",
-            "rental_agreement", "passport_registration" and "temporary_registration" types.
+            files with documents provided by the user; available only for "utility_bill", 
+            "bank_statement", "rental_agreement", "passport_registration" and 
+            "temporary_registration" types.
 
             .. versionchanged:: 20.0
 
@@ -112,20 +111,19 @@ class EncryptedPassportElement(TelegramObject):
                 * |alwaystuple|
 
         front_side (:class:`telegram.PassportFile`): Optional. Encrypted/decrypted file with the
-            front side of the document, provided by the user. Available for "passport",
+            front side of the document, provided by the user; available only for "passport",
             "driver_license", "identity_card" and "internal_passport".
         reverse_side (:class:`telegram.PassportFile`): Optional. Encrypted/decrypted file with the
-            reverse side of the document, provided by the user. Available for "driver_license" and
-            "identity_card".
+            reverse side of the document, provided by the user; available only for "driver_license"
+            and "identity_card".
         selfie (:class:`telegram.PassportFile`): Optional. Encrypted/decrypted file with the
-            selfie of the user holding a document, provided by the user; available for "passport",
-            "driver_license", "identity_card" and "internal_passport".
+            selfie of the user holding a document, provided by the user; available if requested for
+            "passport", "driver_license", "identity_card" and "internal_passport".
         translation (Tuple[:class:`telegram.PassportFile`]): Optional. Array of
-            encrypted/decrypted
-            files with translated versions of documents provided by the user. Available if
-            requested for "passport", "driver_license", "identity_card", "internal_passport",
-            "utility_bill", "bank_statement", "rental_agreement", "passport_registration" and
-            "temporary_registration" types.
+            encrypted/decrypted files with translated versions of documents provided by the user;
+            available if requested for "passport", "driver_license", "identity_card",
+            "internal_passport", "utility_bill", "bank_statement", "rental_agreement",
+            "passport_registration" and "temporary_registration" types.
 
             .. versionchanged:: 20.0
 
